@@ -4,11 +4,10 @@ from loguru import logger
 
 
 class InterceptHandler(logging.Handler):
-
-    def __init__(self, level=logging.NOTSET) -> None:
+    def __init__(self, level: int = logging.NOTSET) -> None:
         super(InterceptHandler, self).__init__(level)
 
-    def emit(self, record):
+    def emit(self, record):  # type: ignore
         # Get corresponding Loguru level if it exists
         try:
             level = logger.level(record.levelname).name
@@ -18,10 +17,9 @@ class InterceptHandler(logging.Handler):
         # Find caller from where originated the logged message
         frame, depth = logging.currentframe(), 2
         while frame.f_code.co_filename == logging.__file__:
-            frame = frame.f_back
+            frame = frame.f_back  # type: ignore
             depth += 1
 
         logger.opt(depth=depth, exception=record.exc_info).log(
-            level,
-            record.getMessage()
+            level, record.getMessage()
         )
