@@ -9,19 +9,20 @@ if TYPE_CHECKING:
 
 
 class ToolsMixin(object):
-    """ Object: ToolsMixin """
+    """Object: ToolsMixin"""
+
     _requests: RequestManager
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> ToolsMixin:
         """Создаем сессию, чтобы не пересоздавать её много раз"""
         await self._requests.create_session()
         return self
 
-    async def close(self):
-        """ shutdown wrapper, close aiohttp session and clear storage """
+    async def close(self) -> None:
+        """shutdown wrapper, close aiohttp session and clear storage"""
         await self._requests.close()
 
-    async def __aexit__(self, exc_type, exc_val, exc_tb):
+    async def __aexit__(self, exc_type, exc_val, exc_tb):  # type: ignore
         """Закрываем сессию и очищаем кэш при выходе"""
         await self.close()
 
@@ -31,47 +32,45 @@ class ToolsMixin(object):
         except AttributeError:
             return None
 
-    def __new__(cls, *args, **kwargs):
-        return super().__new__(cls, *args, **kwargs)
-
-    def __deepcopy__(self, memo):
+    def __deepcopy__(self, memo: Any) -> ToolsMixin:
         cls = self.__class__
         kw: Dict[str, bool] = {"__copy_signal__": True}
-        result = cls.__new__(cls, **kw)
+        result = cls.__new__(cls, **kw)  # type: ignore  # pragma: no cover
         memo[id(self)] = result
         dct = {
-            slot: self._get(slot) for slot in self.__slots__ if
-            self._get(slot) is not None
+            slot: self._get(slot)
+            for slot in self.__slots__
+            if self._get(slot) is not None
         }
         for k, value in dct.items():
-            if k == '_requests':
+            if k == "_requests":
                 value._session = None
-            elif k == 'dispatcher':
+            elif k == "dispatcher":
                 value._loop = None
-            setattr(result, k, copy.deepcopy(value, memo))
-        return result
+            setattr(result, k, copy.deepcopy(value, memo))  # NOQA
+        return cast(ToolsMixin, result)
 
     @property
-    def data(self):
-        data = getattr(self, '_data', None)
+    def data(self):  # type: ignore
+        data = getattr(self, "_data", None)
         if data is None:
             data = {}
-            setattr(self, '_data', data)
+            setattr(self, "_data", data)
         return data
 
-    def __getitem__(self, item):
+    def __getitem__(self, item: Any) -> Any:
         return self.data[item]
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key: Any, value: Any) -> None:
         self.data[key] = value
 
-    def __delitem__(self, key):
+    def __delitem__(self, key: Any) -> None:
         del self.data[key]
 
-    def __contains__(self, key):
+    def __contains__(self, key: Any) -> bool:
         return key in self.data
 
-    def get(self, key, default=None):
+    def get(self, key, default=None):  # type: ignore
         return self.data.get(key, default)
 
 
@@ -87,9 +86,9 @@ class ContextInstanceMixin(Generic[ContextInstance]):
 
     @classmethod  # noqa: F811
     def get_current(  # noqa: F811
-            cls, no_error: bool = True
+        cls, no_error: bool = True
     ) -> Optional[ContextInstance]:  # pragma: no cover  # noqa: F811
-        """ Get current instance from context """
+        """Get current instance from context"""
         # on mypy 0.770 I catch that contextvars.ContextVar always contextvars.ContextVar[Any]
         cls.__context_instance = cast(
             contextvars.ContextVar[ContextInstance], cls.__context_instance
