@@ -25,20 +25,15 @@ class Path:
 
 
 E = typing.TypeVar("E")
-EventFilter = typing.Callable[[E], bool]
-EventHandlerFunctor = typing.Callable[[E], typing.Awaitable[typing.Any]]
 CF = typing.Callable[[E], typing.Union[typing.Awaitable[bool], bool]]
 
 __all__ = (
-    'DEFAULT_QIWI_WEBHOOK_PATH',
-    'DEFAULT_QIWI_ROUTER_NAME',
-    'DEFAULT_QIWI_BILLS_WEBHOOK_PATH',
-    'DEFAULT_QIWI_BILLS_ROUTER_NAME',
-    'RESPONSE_TIMEOUT',
-    'allowed_ips',
-    'Path',
-    'E',
-    'EventFilter',
-    'EventHandlerFunctor',
-    'CF'
+    "DEFAULT_QIWI_WEBHOOK_PATH",
+    "DEFAULT_QIWI_ROUTER_NAME",
+    "DEFAULT_QIWI_BILLS_WEBHOOK_PATH",
+    "DEFAULT_QIWI_BILLS_ROUTER_NAME",
+    "RESPONSE_TIMEOUT",
+    "allowed_ips",
+    "Path",
+    "CF",
 )
