@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from dataclasses import dataclass
-from typing import Union, Any, Optional
+from typing import Union, Any, Optional, Tuple, Dict
 
 from pydantic import BaseModel, validator
 
@@ -11,11 +13,12 @@ class Sum(BaseModel):
     Сумма платежа
 
     """
+
     amount: Union[int, float, str]
     currency: Any
 
     @validator("currency", pre=True)
-    def humanize_pay_currency(cls, v):
+    def humanize_pay_currency(cls, v):  # type: ignore
         from glQiwiApi.utils.currency_util import Currency
 
         if not isinstance(v, int):
@@ -27,7 +30,8 @@ class Sum(BaseModel):
 
 
 class OptionalSum(BaseModel):
-    """ object: OptionalSum """
+    """object: OptionalSum"""
+
     value: Union[int, float]
     currency: str
 
@@ -37,6 +41,7 @@ class Type(BaseModel):
     Базовая модель типа данных
 
     """
+
     id: str
     title: str
 
@@ -47,16 +52,16 @@ class Attributes:
     Аттрибуты кэшированного запроса
 
     """
-    headers: Optional[dict] = None
-    json: Optional[dict] = None
-    params: Optional[dict] = None
-    data: Optional[dict] = None
+
+    headers: Optional[Dict[Any, Any]] = None
+    json: Optional[Dict[Any, Any]] = None
+    params: Optional[Dict[Any, Any]] = None
+    data: Optional[Dict[Any, Any]] = None
 
     @classmethod
-    def format(cls, kwargs: dict, args: tuple):
+    def format(cls, kwargs: Dict[Any, Any], args: Tuple[Any, ...]) -> Attributes:
         return cls(
-            **{k: kwargs.get(k) for k in args if
-               isinstance(kwargs.get(k), dict)}
+            **{k: kwargs.get(k) for k in args if isinstance(kwargs.get(k), dict)}
         )
 
 
@@ -66,17 +71,10 @@ class Cached:
     Объект кэшированного запроса
 
     """
+
     kwargs: Attributes
     response_data: Any
     method: Optional[Any]
-    status_code: Union[str, int, None] = None
 
 
-__all__ = [
-    'Sum',
-    'OptionalSum',
-    'Type',
-    'Cached',
-    'DEFAULT_CACHE_TIME',
-    'Attributes'
-]
+__all__ = ["Sum", "OptionalSum", "Type", "Cached", "DEFAULT_CACHE_TIME", "Attributes"]
