@@ -9,24 +9,23 @@ from glQiwiApi.utils.currency_util import Currency
 
 
 class Account(Base):
-    """ object: Account """
+    """object: Account"""
+
     alias: str
     title: str
     fs_alias: str = Field(alias="fsAlias")
     bank_alias: str = Field(alias="bankAlias")
     has_balance: bool = Field(alias="hasBalance")
-    balance: Optional[Sum] = Field(const=None)
+    balance: Optional[Sum] = None
     currency: CurrencyModel
     account_type: Optional[Type] = Field(None, alias="type")
     is_default_account: bool = Field(alias="defaultAccount")
 
-    @validator("currency", pre=True, check_fields=True)
-    def humanize_pay_currency(cls, v):
+    @validator("currency", pre=True)
+    def humanize_pay_currency(cls, v):  # type: ignore
         if not isinstance(v, int):
             return v
         return Currency.get(str(v))
 
 
-__all__ = (
-    'Account'
-)
+__all__ = "Account"
