@@ -8,47 +8,49 @@ from glQiwiApi.types.basics import OptionalSum
 
 
 class Customer(Base):
-    """ Object: Customer """
+    """Object: Customer"""
+
     phone: Optional[str] = None
     email: Optional[str] = None
     account: Optional[str] = None
 
 
 class BillStatus(Base):
-    """ Object: BillStatus """
+    """Object: BillStatus"""
+
     value: str
-    changed_datetime: datetime = Field(alias="changedDateTime")
+    changed_datetime: datetime = Field(..., alias="changedDateTime")
 
 
 class CustomFields(Base):
-    """ Object: CustomFields """
-    pay_sources_filter: Optional[str] = Field(alias="paySourcesFilter",
-                                              default=None)
-    theme_code: Optional[str] = Field(alias="themeCode", default=None)
+    """Object: CustomFields"""
+
+    pay_sources_filter: Optional[str] = Field(None, alias="paySourcesFilter")
+    theme_code: Optional[str] = Field(None, alias="themeCode")
 
 
 class BillError(Base):
-    """ Object: BillError """
-    service_name: str = Field(alias="serviceName")
-    error_code: str = Field(alias="errorCode")
+    """Object: BillError"""
+
+    service_name: str = Field(..., alias="serviceName")
+    error_code: str = Field(..., alias="errorCode")
     description: str
-    user_message: str = Field(alias="userMessage")
-    datetime: str = Field(alias="dateTime")
-    trace_id: str = Field(alias="traceId")
+    user_message: str = Field(..., alias="userMessage")
+    datetime: str = Field(..., alias="dateTime")
+    trace_id: str = Field(..., alias="traceId")
 
 
 class Bill(Base):
-    """ Object: Bill """
-    site_id: str = Field(alias="siteId")
-    bill_id: str = Field(alias="billId")
+    """Object: Bill"""
+
+    site_id: str = Field(..., alias="siteId")
+    bill_id: str = Field(..., alias="billId")
     amount: OptionalSum
     status: BillStatus
-    creation_date_time: datetime = Field(alias="creationDateTime")
-    expiration_date_time: datetime = Field(alias="expirationDateTime")
-    pay_url: Optional[str] = Field(alias="payUrl", default=None)
-    custom_fields: Optional[
-        CustomFields
-    ] = Field(alias="customFields", default=None)
+    creation_date_time: datetime = Field(..., alias="creationDateTime")
+    expiration_date_time: datetime = Field(..., alias="expirationDateTime")
+    pay_url: Optional[str] = Field(None, alias="payUrl")
+    custom_fields: Optional[CustomFields] = Field(None, alias="customFields")
     customer: Optional[Customer] = None
 
     class Config:
@@ -66,9 +68,7 @@ class Bill(Base):
         Checking p2p payment
 
         """
-        return (await self.client.check_p2p_bill_status(
-            bill_id=self.bill_id
-        )) == 'PAID'
+        return (await self.client.check_p2p_bill_status(bill_id=self.bill_id)) == "PAID"
 
 
 class RefundBill(Base):
@@ -76,6 +76,7 @@ class RefundBill(Base):
     Модель счёта киви апи
 
     """
+
     amount: OptionalSum
     datetime: datetime
     refund_id: str = Field(..., alias="refundId")
@@ -92,10 +93,12 @@ class Notification(Base):
     """Object: Notification"""
 
     version: str = Field(..., alias="version")
-    bill: Bill = Field(..., alias="bill")
+    bill: Optional[Bill] = Field(default=None, alias="bill")
 
     def __str__(self) -> str:
-        return f"#{self.bill.bill_id} {self.bill.amount} {self.bill.status} "
+        if isinstance(self.bill, Bill):
+            return f"#{self.bill.bill_id} {self.bill.amount} {self.bill.status} "
+        return f"Test notification. QIWI API version -> {self.version}"
 
     def __repr__(self) -> str:
         return self.__str__()
@@ -106,10 +109,4 @@ class P2PKeys(Base):
     secret_key: str = Field(..., alias="SecretKey")
 
 
-__all__ = (
-    'Bill',
-    'BillError',
-    'RefundBill',
-    'Notification',
-    'P2PKeys'
-)
+__all__ = ("Bill", "BillError", "RefundBill", "Notification", "P2PKeys")
