@@ -6,7 +6,8 @@ from pydantic import BaseModel, Field
 
 
 class BalanceDetails(BaseModel):
-    """ object: BalanceDetails """
+    """object: BalanceDetails"""
+
     total: float
     available: float
     deposition_pending: Optional[float] = None
@@ -16,13 +17,14 @@ class BalanceDetails(BaseModel):
 
 
 class CardsLinked(BaseModel):
-    """ object: CardsLinked """
+    """object: CardsLinked"""
+
     pan_fragment: str
     type: str
 
 
 class AccountInfo(BaseModel):
-    """ object: AccountInfo"""
+    """object: AccountInfo"""
 
     account: str
     """Номер счета"""
@@ -88,13 +90,14 @@ class OperationType(Enum):
     непринятые входящие P2P-переводы любого типа.
 
     """
-    DEPOSITION = 'deposition'
+
+    DEPOSITION = "deposition"
     """Пополнение счета (приход);"""
 
-    PAYMENT = 'payment'
+    PAYMENT = "payment"
     """Платежи со счета (расход)"""
 
-    TRANSFERS = 'incoming-transfers-unaccepted'
+    TRANSFERS = "incoming-transfers-unaccepted"
     """непринятые входящие P2P-переводы любого типа."""
 
 
@@ -105,13 +108,14 @@ class DigitalGoods(BaseModel):
     Описание формата:
     https://yoomoney.ru/docs/wallet/process-payments/process-payment#digital-goods
     """
+
     article_id: str = Field(..., alias="merchantArticleId")
     serial: str
     secret: str
 
 
 class Operation(BaseModel):
-    """ object: Operation """
+    """object: Operation"""
 
     operation_id: str
     """Идентификатор операции."""
@@ -171,7 +175,8 @@ class Operation(BaseModel):
 
 
 class OperationDetails(BaseModel):
-    """ object: OperationDetails """
+    """object: OperationDetails"""
+
     operation_id: Optional[str] = None
     """Идентификатор операции. Можно получить при вызове метода history()"""
 
@@ -315,12 +320,14 @@ class OperationDetails(BaseModel):
 
 
 class Wallet(BaseModel):
-    """ object: Wallet """
+    """object: Wallet"""
+
     allowed: bool
 
 
 class Item(BaseModel):
-    """ object: Item """
+    """object: Item"""
+
     item_id: str = Field(..., alias="id")
     """
     Идентификатор привязанной к счету банковской карты.
@@ -344,7 +351,8 @@ class Item(BaseModel):
 
 
 class Card(BaseModel):
-    """ object: Card"""
+    """object: Card"""
+
     allowed: bool
     csc_required: bool
     items: List[Item]
@@ -355,6 +363,7 @@ class MoneySource(BaseModel):
     Список доступных методов для проведения данного платежа.
     Каждый метод содержит набор атрибутов.
     """
+
     wallet: Wallet
     """платеж со счета пользователя"""
     cards: Optional[Card] = None
@@ -368,6 +377,7 @@ class PreProcessPaymentResponse(BaseModel):
     а условно подготавливаете его к отправке.
     Для отправки денег на счёт используйте метод send()
     """
+
     status: str
     request_id: str
     recipient_account_status: str
@@ -386,7 +396,8 @@ class PreProcessPaymentResponse(BaseModel):
 
 
 class Payment(BaseModel):  # lgtm [py/missing-equals #
-    """ object: Payment """
+    """object: Payment"""
+
     status: str
     """
     Код результата выполнения операции. Возможные значения:
@@ -480,13 +491,14 @@ class Payment(BaseModel):  # lgtm [py/missing-equals #
     при передаче аргументов
     """
 
-    def initialize(self, protection_code: Optional[str]) -> 'Payment':
+    def initialize(self, protection_code: Optional[str]) -> "Payment":
         self.protection_code = protection_code
         return self
 
 
 class IncomingTransaction(BaseModel):
-    """ object: IncomingTransaction """
+    """object: IncomingTransaction"""
+
     status: str
     protection_code_attempts_available: int
     ext_action_uri: Optional[str] = None
@@ -494,11 +506,12 @@ class IncomingTransaction(BaseModel):
 
 
 __all__ = (
-    'AccountInfo',
-    'OperationType',
-    'Operation',
-    'OperationDetails',
-    'PreProcessPaymentResponse',
-    'Payment',
-    'IncomingTransaction'
+    "AccountInfo",
+    "OperationType",
+    "Operation",
+    "OperationDetails",
+    "PreProcessPaymentResponse",
+    "Payment",
+    "IncomingTransaction",
+    "Card",
 )
